;***********************************************************************
;**                                                                   **
;**    Asymmetrical Playfield With Multi Vertical Scrolling V1.00     **
;**                Christian Bogey - April 17,2004                    **
;**                                                                   **
;***********************************************************************


                processor 6502 
                include "vcs.h" 
                include "macro.h" 
                
;-----------------------------------------------------------------------
;-                          Define Variables                           -
;-----------------------------------------------------------------------
                       ; Right Playfield Pattern for current Frame 
PF0ADR = $80           ; 1st byte in RAM
PF1ADR = $81
PF2ADR = $82

PF0TMP = $83           ; Right Playfield Pattern of the 1st line
PF1TMP = $84           ; to draw for the current Frame
PF2TMP = $85

PF0DATA = #%11001100   ; Right Playfield Patterns (Init Values)	
PF1DATA = #%00100011
PF2DATA = #%10101111

;-----------------------------------------------------------------------
;-                         Start of code here                          -
;-----------------------------------------------------------------------

                SEG 
                ORG $F000 

Reset 

;-----------------------------------------------------------------------
;-        Clear RAM, TIA registers and Set Stack Pointer to #$FF       -                               
;-----------------------------------------------------------------------
        
                SEI
                CLD	
                LDX #$FF
                TXS
                LDA #0
Clear_Mem
                STA 0,X
                DEX
                BNE Clear_Mem	

                LDA #PF0DATA     ; Init Playfield Pattern
                STA PF0TMP
                LDA #PF1DATA
                STA PF1TMP
                LDA #PF2DATA
                STA PF2TMP
               
                LDA #0
                STA COLUBK       ; Background = Black     
                LDA #%00000010   ; Active Score Bit = 2 Colors for Playfield
                STA CTRLPF
                LDA #$48
                STA COLUP0
                LDA #$B8
                STA COLUP1
		

;-----------------------------------------------------------------------
;-                         Start to Build Frame                        -
;-----------------------------------------------------------------------				

Start_Frame 

         
        ; Start of Vertical Blank 

                LDA #2 
                STA VSYNC 

                STA WSYNC 
                STA WSYNC 
                STA WSYNC   ; 3 scanlines of VSYNC

                LDA #0 
                STA VSYNC            
                

        ; 37 Scanlines of Vertical Blank
                         
                LDX #36
Vertical_Blank   
                STA WSYNC 
                DEX 
                BNE Vertical_Blank 
                
                LDA PF0TMP       ; Load Pattern
                STA PF0ADR       ; for current loop
                LDA PF1TMP
                STA PF1ADR
                LDA PF2TMP
                STA PF2ADR
                
                DEC PF0TMP	; Build Pattern to scroll
                INC PF1TMP      ; for the Next loop
                DEC PF2TMP
                
                STA WSYNC        ;+1 = 37
                LDA #0 
                STA VBLANK       ; Enable TIA Output
                                
      
        ; Display 192 Scanlines of Asymetrical Playfield with
        ; Multi Scrolling effect of Playfield 2
		
                LDY #48
                LDX #4
Picture
                LDA #%01010000
                STA PF0
                LDA #%00011000
                STA PF1
                LDA #%10111100
                STA PF2
		
                SLEEP 4
                LDA PF0ADR
                STA PF0
                SLEEP 4
                LDA PF1ADR
                STA PF1
                SLEEP 4
                LDA PF2ADR
                STA PF2
		
                STA WSYNC               
	        DEX
                BNE Picture
                
                DEY
                BEQ Picture_End
                LDA #%01010000
                STA PF0
                LDA #%00011000
                STA PF1
                LDA #%10111100
                STA PF2
                INC PF0ADR       ; Change Pattern PF0
                LDA PF0ADR
                STA PF0
                INC PF1ADR       ; Change Pattern PF1
                LDA PF1ADR
                STA PF1
                INC PF2ADR       ; Change Pattern PF2
                LDA PF2ADR
                STA PF2
                LDX #3		; 3 Scanlines To Draw
                STA WSYNC	;+1 (The Currenr One) = 4
                JMP Picture
                
Picture_End                

;-----------------------------------------------------------------------
;-                            Frame Ends Here                          -
;-----------------------------------------------------------------------
    		
                LDA #%01000010 
                STA VBLANK       ; Disable TIA Output 


        ; 30 Scanlines of Overscan
        
                LDX #30 
Overscan        
                STA WSYNC 
                DEX 
                BNE Overscan 

                JMP Start_Frame  ; Build Next Frame 


;-----------------------------------------------------------------------
;-                          Set Interrup Vectors                       -
;-----------------------------------------------------------------------


            ORG $FFFA 

Interrupt_Vectors 

            .word Reset          ; NMI 
            .word Reset          ; RESET 
            .word Reset          ; IRQ 

          END 

